###################################################
### chunk number 1: preliminaries
###################################################
options(prompt = "R> ")


###################################################
### chunk number 2: 
###################################################
library("clues")


###################################################
### chunk number 3: 
###################################################
WDBC <- read.table("WDBC.dat", sep = ",", header = FALSE)
colnames(WDBC) <- c("ID", "caco", paste("dim", 1:30, sep=""))

# the true cluster membership
WDBC.mem <- rep(NA, length(WDBC$caco))
WDBC.mem[WDBC$caco == "M"] <- 1
WDBC.mem[WDBC$caco == "B"] <- 2

head(WDBC[, 1:6])


###################################################
### chunk number 4: 
###################################################
sdVec <- apply(WDBC[, -c(1:2)], 2, sd)
round(quantile(sdVec), 3)


###################################################
### chunk number 5: 
###################################################
dat <- as.matrix(WDBC[ , -c(1:2)])
dat.s <- apply(dat, 2, scale, center = TRUE, scale = TRUE)
colnames(dat.s)<-colnames(WDBC)[-c(1:2)]

res.sil <- clues(dat.s, strengthMethod = "sil", disMethod = "Euclidean")


###################################################
### chunk number 6: 
###################################################
summary(res.sil)


###################################################
### chunk number 7: fig1 eval=FALSE
###################################################
## plotClusters(dat.s, res.sil$mem, plot.dim = c(1, 4, 9, 10),
##   cex.points = 0.01)


###################################################
### chunk number 8: fig1a
###################################################
plotClusters(dat.s, res.sil$mem, plot.dim = c(1, 4, 9, 10),
  cex.points = 0.01)


###################################################
### chunk number 9: fig2 eval=FALSE
###################################################
## plotAvgCurves(dat.s, res.sil$mem, cex.axis=0.3, ylim=c(-1, 1.5),
##   las=1, cex.axis=1)


###################################################
### chunk number 10: fig2a
###################################################
plotAvgCurves(dat.s, res.sil$mem, cex.axis=0.3, ylim=c(-1, 1.5),
  las=1, cex.axis=1)


###################################################
### chunk number 11: 
###################################################
get_Silhouette(dat.s,res.sil$mem)$avg.s


###################################################
### chunk number 12: 
###################################################
accuracy <- sum(WDBC.mem == res.sil$mem) / length(WDBC.mem)
round(accuracy, 2)

library("cluster")
set.seed(12345)
res.km <- kmeans(dat.s, 2, algorithm = "MacQueen")
res.pam <- pam(dat.s, 2)

accuracy.km <- sum(WDBC.mem == res.km$cluster) / length(WDBC.mem)
round(accuracy.km, 2)

accuracy.pam <- sum(WDBC.mem == res.pam$clustering) / length(WDBC.mem)
round(accuracy.pam, 2)


###################################################
### chunk number 13: 
###################################################
res.CH <- clues(dat.s, strengthMethod = "CH", quiet = TRUE)
memMat <- cbind(WDBC.mem, res.sil$mem, res.CH$mem, res.km$cluster, res.pam$clustering)
colnames(memMat) <- c("true", "clues.sil", "clues.CH", "km", "pam")
res<-compClust(dat.s, memMat)
print(sapply(res, round, digits = 2))


###################################################
### chunk number 14: fig3 eval=FALSE
###################################################
## pairs(jj, pch = 21, bg = c("red", "yellow", "purple")[unclass(iris$Species)])


###################################################
### chunk number 15: fig4 eval=FALSE
###################################################
## pairs(shrinkres_jitter[, 1:4], pch = 21, bg = c("red", "purple", "yellow")[unclass(shrinkres_group)])


###################################################
### chunk number 16: 
###################################################
data("iris")
jj <- as.matrix(iris[,1:4])
pairs(jj, pch = 21, bg = c("red", "yellow", "purple")[unclass(iris$Species)])
shrinkres <- shrinking(jj, K = 60, disMethod = "Euclidean", itmax = 3)
dimnames(shrinkres) <- dimnames(jj)
convergepnts <- shrinkres[c(1, 51, 52, 54), ]
row1 <- t(matrix(jitter(rep(convergepnts[1, ], 50)), nrow = 4))
row2 <- t(matrix(jitter(rep(convergepnts[2, ], 51)), nrow = 4))
row3 <- t(matrix(jitter(rep(convergepnts[3, ], 18)), nrow = 4))
row4 <- t(matrix(jitter(rep(convergepnts[4, ], 31)), nrow = 4))
shrinkres_jitter <- rbind(row1, row2, row3, row4)
shrinkres_group <- as.factor(rep(1:3, c(50, 51, 49)))
colnames(shrinkres_jitter) <- colnames(shrinkres) 
pairs(shrinkres_jitter[, 1:4], pch = 21, bg = c("red", "purple", "yellow")[unclass(shrinkres_group)])


###################################################
### chunk number 17: fig3a
###################################################
pairs(jj, pch = 21, bg = c("red", "yellow", "purple")[unclass(iris$Species)])


###################################################
### chunk number 18: fig4a
###################################################
pairs(shrinkres_jitter[, 1:4], pch = 21, bg = c("red", "purple", "yellow")[unclass(shrinkres_group)])


